@@ -67,7 +67,7 @@ const QStringList GmlFileFormatPlugin::extensions() const
 void GmlFileFormatPlugin::readFile()
 {
     Document * graphDoc = new Document(i18n("Import"));
-    DataStructureBackendManager::self()->setBackend("Graph");
+    DataStructureBackendManager::self().setBackend("Graph");
 
     QList < QPair<QString, QString> > edges;
     QFile fileHandle(file().toLocalFile());
